@@ -50,11 +50,11 @@ SVK::Command::Propedit - Edit a property on path
 
 =head1 OPTIONS
 
- -m [--message] arg     : specify commit message ARG
+ -m [--message] MESSAGE	: specify commit message MESSAGE
  -C [--check-only]      : try operation but make no changes
  -R [--recursive]       : descend recursively
- -r [--revision] arg    : act on revision ARG instead of the head revision
- -P [--patch] arg       : instead of commit, save this change as a patch
+ -r [--revision] REV	: act on revision REV instead of the head revision
+ -P [--patch] NAME	: instead of commit, save this change as a patch
  -S [--sign]            : sign this change
  --revprop              : operate on a revision property (use with -r)
  --direct               : commit directly even if the path is mirrored
